@@ -2,8 +2,8 @@ from simpleicons.icon import Icon
 teamviewer_icon= Icon(
     title="TeamViewer",
     slug="teamviewer",
-    hex="0E8EE9",
-    source="https://www.teamviewer.com/resources/images/logos/teamviewer-logo-big.svg",
+    hex="004680",
+    source="https://www.teamviewer.com/en-us/",
     svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>TeamViewer</title><path d="M22.597 24H1.406A1.41 1.41 0 0 1 0 22.594V1.406A1.41 1.41 0 0 1 1.406 0h21.191a1.41 1.41 0 0 1 1.406 1.406v21.188A1.41 1.41 0 0 1 22.597 24zM11.911 2.109c-5.405.047-9.763 4.482-9.802 9.89-.04 5.507 4.381 9.885 9.89 9.89 5.415.003 9.796-4.5 9.89-9.89.097-5.572-4.406-9.939-9.978-9.89zM9.65 8.633l-.889 2.159H15.3l-.889-2.159 6.642 3.365-6.642 3.365.889-2.159H8.761l.882 2.159-6.659-3.365z"/></svg>""",
     guidelines=None,
     license=None,
